========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |travis|
        | |coveralls|
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations|
        | |commits-since|
.. |docs| image:: https://readthedocs.org/projects/kotonoha/badge/?style=flat
    :target: https://readthedocs.org/projects/kotonoha
    :alt: Documentation Status

.. |travis| image:: https://travis-ci.org/brunotoshio/kotonoha.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/brunotoshio/kotonoha

.. |coveralls| image:: https://coveralls.io/repos/brunotoshio/kotonoha/badge.svg?branch=master&service=github
    :alt: Coverage Status
    :target: https://coveralls.io/r/brunotoshio/kotonoha

.. |version| image:: https://img.shields.io/pypi/v/kotonoha.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/kotonoha

.. |commits-since| image:: https://img.shields.io/github/commits-since/brunotoshio/kotonoha/v0.0.0.svg
    :alt: Commits since latest release
    :target: https://github.com/brunotoshio/kotonoha/compare/v0.0.0...master

.. |wheel| image:: https://img.shields.io/pypi/wheel/kotonoha.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/kotonoha

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/kotonoha.svg
    :alt: Supported versions
    :target: https://pypi.org/project/kotonoha

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/kotonoha.svg
    :alt: Supported implementations
    :target: https://pypi.org/project/kotonoha


.. end-badges

Tools for preprocessing Japanese texts

* Free software: MIT license
